==> MeatAxe-2.4.8.tar.gz: mtx/2.4/src/imatcore.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: imatcore.c,v 1.1.1.1 2000/01/07 16:42:26 mringe Exp $
   Comment:     Basic integer matrix functions.
   --------------------------------------------------------------------------
   (C) Copyright 1999 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */

#include "meataxe.h"
#include <string.h>

   
/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO

#define IMAT_MAGIC 0x396AA2F2

   
   

/*{{{ --------------------------------------------------------------------------
!definesection obj.imat
\index{IntMatrix_t@{\tt IntMatrix\protect\_t} data type}
The |IntMatrix_t| data type represents a matrix with integer entries.
-------------------------------------------------------------------------- }}}*/


/*{{{ --------------------------------------------------------------------------
!section obj.imat
!function ImatIsValid "Check an integer matrix"
!arg mat
    Pointer to the matrix.
!return
    1 if |mat| points to a valid matrix, 0 otherwise.
!description
    This function checks if the argument |mat| is a pointer to a valid
    integer matrix. If the matrix is o.k., the function returns 1. Otherwise, 
    an error is signaled and, if the error handler does not terminate the 
    program, the function returns 0.
!seealso IntMatrix_t
-------------------------------------------------------------------------- }}}*/

int ImatIsValid(const IntMatrix_t *mat)

{
    if (mat == NULL)
    {
	MTX_ERROR("NULL matrix");
	return 0;
    }
    if (mat->Magic != IMAT_MAGIC || mat->Nor < 0 || mat->Noc < 0)
    {
	MTX_ERROR2("Invalid matrix (nor=%d, noc=%d)",mat->Nor,mat->Noc);
	return 0;
    }
    return 1;

}




/*{{{ --------------------------------------------------------------------------
!function ImatAlloc "Create a new integer matrix"
!arg nor
    Number of rows.
!arg noc
    Number of columns.
!return
    Pointer to the new matrix or |NULL| on error.
!description
    This function creates a new integer matrix with |nor| rows and |noc|
    columns. The return value is a pointer to the allocated |IntMatrix_t| 
    structure, or |NULL| if there is not enough memory. 
    To destroy an integer matrix, use |ImatFree()|, {\em not} \verb"SysFree()".
!seealso ImatFree IntMatrix_t
-------------------------------------------------------------------------- }}}*/

IntMatrix_t *ImatAlloc(int nor, int noc)

{
    IntMatrix_t *m;

    MTX_VERIFY(nor >= 0);
    MTX_VERIFY(noc >= 0);

    /* Allocate a new Matrix_t structure
       --------------------------------- */
    m = ALLOC(IntMatrix_t);
    if (m == NULL)
    {
	MTX_ERROR("Cannot allocate IntMatrix_t structure");
	return NULL;
    }

    /* Initialize the data structure
       ----------------------------- */
    m->Magic = IMAT_MAGIC;
    m->Nor = nor;
    m->Noc = noc;
    m->Data = NALLOC(long,nor * noc);
    if (m->Data == NULL)
    {
	SysFree(m);
	MTX_ERROR("Cannot allocate matrix data");
	return NULL;
    }
    return m;
}








/*{{{ --------------------------------------------------------------------------
!function ImatFree "Delete a matrix"
!arg mat
    Pointer to the matrix.
!return
    $0$ on success, $-1$ on error.
!description
    This function frees a matrix which has beed created by |ImatAlloc()|. This
    implies freeing the internal data buffers as well as the |IntMatrix_t| 
    structure itself.
!seealso ImatAlloc IntMatrix_t
-------------------------------------------------------------------------- }}}*/

int ImatFree(IntMatrix_t *mat)

{
    if (!ImatIsValid(mat))
	return -1;
    if (mat->Data != NULL)
	SysFree(mat->Data);
    memset(mat,0,sizeof(IntMatrix_t));
    SysFree(mat);
    return 0;
}

==> MeatAxe-2.4.9.tar.gz: mtx/2.4/src/imatcore.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: imatcore.c,v 1.1.1.1 2007/09/02 11:06:17 mringe Exp $
   Comment:     Basic integer matrix functions.
   --------------------------------------------------------------------------
   (C) Copyright 1999 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */

#include "meataxe.h"
#include <string.h>

   
/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO

#define IMAT_MAGIC 0x396AA2F2

   
   

/**
!definesection obj.imat
\index{IntMatrix_t@{\tt IntMatrix\protect\_t} data type}
The |IntMatrix_t| data type represents a matrix with integer entries.
 **/


/**
!section obj.imat
!function ImatIsValid "Check an integer matrix"
 ** @param mat
    Pointer to the matrix.
 ** @return
    1 if |mat| points to a valid matrix, 0 otherwise.
!description
    This function checks if the argument |mat| is a pointer to a valid
    integer matrix. If the matrix is o.k., the function returns 1. Otherwise, 
    an error is signaled and, if the error handler does not terminate the 
    program, the function returns 0.
 ** @see IntMatrix_t
 **/

int ImatIsValid(const IntMatrix_t *mat)

{
    if (mat == NULL)
    {
	MTX_ERROR("NULL matrix");
	return 0;
    }
    if (mat->Magic != IMAT_MAGIC || mat->Nor < 0 || mat->Noc < 0)
    {
	MTX_ERROR2("Invalid matrix (nor=%d, noc=%d)",mat->Nor,mat->Noc);
	return 0;
    }
    return 1;

}




/**
!function ImatAlloc "Create a new integer matrix"
 ** @param nor
    Number of rows.
 ** @param noc
    Number of columns.
 ** @return
    Pointer to the new matrix or |NULL| on error.
!description
    This function creates a new integer matrix with |nor| rows and |noc|
    columns. The return value is a pointer to the allocated |IntMatrix_t| 
    structure, or |NULL| if there is not enough memory. 
    To destroy an integer matrix, use |ImatFree()|, {\em not} \verb"SysFree()".
 ** @see ImatFree IntMatrix_t
 **/

IntMatrix_t *ImatAlloc(int nor, int noc)

{
    IntMatrix_t *m;

    MTX_VERIFY(nor >= 0);
    MTX_VERIFY(noc >= 0);

    /* Allocate a new Matrix_t structure
       --------------------------------- */
    m = ALLOC(IntMatrix_t);
    if (m == NULL)
    {
	MTX_ERROR("Cannot allocate IntMatrix_t structure");
	return NULL;
    }

    /* Initialize the data structure
       ----------------------------- */
    m->Magic = IMAT_MAGIC;
    m->Nor = nor;
    m->Noc = noc;
    m->Data = NALLOC(long,nor * noc);
    if (m->Data == NULL)
    {
	SysFree(m);
	MTX_ERROR("Cannot allocate matrix data");
	return NULL;
    }
    return m;
}








/**
!function ImatFree "Delete a matrix"
 ** @param mat
    Pointer to the matrix.
 ** @return
    $0$ on success, $-1$ on error.
!description
    This function frees a matrix which has beed created by |ImatAlloc()|. This
    implies freeing the internal data buffers as well as the |IntMatrix_t| 
    structure itself.
 ** @see ImatAlloc IntMatrix_t
 **/

int ImatFree(IntMatrix_t *mat)

{
    if (!ImatIsValid(mat))
	return -1;
    if (mat->Data != NULL)
	SysFree(mat->Data);
    memset(mat,0,sizeof(IntMatrix_t));
    SysFree(mat);
    return 0;
}
